# Changelog

- This file provides a full account of all changes to `dbt-spark`
- The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
and is generated by [Changie](https://github.com/miniscruff/changie)
- Changes are listed under the (pre-)release in which they first appear
- Subsequent releases include changes from previous releases
- "Breaking changes" listed under a version may require action from end users or external maintainers when upgrading to that version
- Do not edit this file directly. This file is auto-generated using [changie](https://github.com/miniscruff/changie)
- For details on how to document a change, see the [contributing guide](/CONTRIBUTING.md#changelog-entry)

## dbt-spark 1.10.1 - February 11, 2026

### Features

- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))

### Dependencies

- Add support for Spark v4.x ([#1537](https://github.com/dbt-labs/dbt-adapters/pull/1537))

### Contributors
- [@thmshmm](https://github.com/thmshmm) ([#1537](https://github.com/dbt-labs/dbt-adapters/pull/1537))


## dbt-spark 1.10.0 - December 22, 2025

### Features

- add query timeout and retry handling for pyhive connections ([#1419](https://github.com/dbt-labs/dbt-adapters/issues/1419))
- add query timeout and retry handling for pyhive connections ([#1419](https://github.com/dbt-labs/dbt-adapters/issues/1419))
- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))

### Fixes

- update alter_relation_add_remove_columns to quote column names ([#63](https://github.com/dbt-labs/dbt-adapters/issues/63))
- update alter_relation_add_remove_columns to quote column names ([#63](https://github.com/dbt-labs/dbt-adapters/issues/63))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
- Cap logbook at less than 1.9 to avoid breaking change ([#N/A](https://github.com/dbt-labs/dbt-adapters/pull/N/A))
- Cap logbook at less than 1.9 to avoid breaking change ([#N/A](https://github.com/dbt-labs/dbt-adapters/pull/N/A))

## dbt-spark 1.9.3 - July 16, 2025

## dbt-spark 1.9.2 - March 07, 2025

### Fixes

- Stop adding aliases to render_limited output for --empty ([#474](https://github.com/dbt-labs/dbt-adapters/issues/474))

### Under the Hood

- Move from setup.py to pyproject.toml and to hatch as a dev tool ([#1150](https://github.com/dbt-labs/dbt-adapters/issues/1150))

### Contributors
- [@anaghshineh](https://github.com/anaghshineh) ([#474](https://github.com/dbt-labs/dbt-adapters/issues/474))

## Previous Releases
For information on prior major and minor releases, see their changelogs:
- [1.9](https://github.com/dbt-labs/dbt-spark/blob/1.9.latest/CHANGELOG.md)
- [1.8](https://github.com/dbt-labs/dbt-spark/blob/1.8.latest/CHANGELOG.md)
- [1.7](https://github.com/dbt-labs/dbt-spark/blob/1.7.latest/CHANGELOG.md)
- [1.6](https://github.com/dbt-labs/dbt-spark/blob/1.6.latest/CHANGELOG.md)
- [1.5](https://github.com/dbt-labs/dbt-spark/blob/1.5.latest/CHANGELOG.md)
- [1.4](https://github.com/dbt-labs/dbt-spark/blob/1.4.latest/CHANGELOG.md)
- [1.3](https://github.com/dbt-labs/dbt-spark/blob/1.3.latest/CHANGELOG.md)
- [1.2](https://github.com/dbt-labs/dbt-spark/blob/1.2.latest/CHANGELOG.md)
- [1.1](https://github.com/dbt-labs/dbt-spark/blob/1.1.latest/CHANGELOG.md)
- [1.0](https://github.com/dbt-labs/dbt-spark/blob/1.0.latest/CHANGELOG.md)
- [0.21](https://github.com/dbt-labs/dbt-spark/blob/0.21.latest/CHANGELOG.md)
- [0.20](https://github.com/dbt-labs/dbt-spark/blob/0.20.latest/CHANGELOG.md)
- [0.19 and earlier](https://github.com/dbt-labs/dbt-spark/blob/0.19.latest/CHANGELOG.md)
